.. _exceptions_ref:

:mod:`nilearn.exceptions`: Exceptions and warnings
==================================================

.. automodule:: nilearn.exceptions
   :no-members:
   :no-inherited-members:

Warnings
--------

.. currentmodule:: nilearn.exceptions

.. autosummary::
   :toctree: generated/
   :template: class.rst

   MaskWarning
   NotImplementedWarning

Exceptions
----------

.. currentmodule:: nilearn.exceptions

.. autosummary::
   :toctree: generated/
   :template: class.rst

   AllVolumesRemovedError
   DimensionError
   MeshDimensionError

.. autoclasstree:: nilearn.exceptions
   :full:
